@@ -55,7 +55,9 @@ namespace octomap {
 
     scan->writeBinary(s);
     pose.writeBinary(s);
-    s.write((char*)&id, sizeof(id));
+
+    uint32_t uintId = static_cast<uint32_t>(id);
+    s.write((char*)&uintId, sizeof(uintId));
 
     return s;
   }
@@ -67,7 +69,9 @@ namespace octomap {
 
     this->pose.readBinary(s);
 
-    s.read((char*)&this->id, sizeof(this->id));
+    uint32_t uintId;
+    s.read((char*)&uintId, sizeof(uintId));
+    this->id = uintId;
 
     return s;
   }
